@@ -11,9 +11,7 @@
 #'
 #' This function was adapted from the igraph wiki (http://igraph.wikidot.com).
 #'
-#' @param g The igraph graph object
-#' @param use.parallel Logical indicating whether or not to use \emph{foreach}
-#'   (default: TRUE)
+#' @param g An \code{igraph} graph object
 #' @export
 #'
 #' @return A vector of the leverage centrality for all vertices.
@@ -22,24 +20,14 @@
 #' @references Joyce K.E., Laurienti P.J., Burdette J.H., Hayasaka S. (2010)
 #' \emph{A new measure of centrality for brain networks}. PLoS One, 5(8):e12200.
 
-centr_lev <- function(g, use.parallel=TRUE) {
-  i <- NULL
+centr_lev <- function(g) {
   stopifnot(is_igraph(g))
 
-  k <- degree(g)
-  n <- vcount(g)
-  lev.cent <- rep(NA, n)
-  inds <- which(k > 0)
-  if (isTRUE(use.parallel)) {
-    lev.cent[inds] <- foreach(i=inds, .combine='c') %dopar% {
-      nbs <- neighbors(g, i)
-      mean((k[i] - k[nbs]) / (k[i] + k[nbs]))
-    }
-  } else {
-    lev.cent[inds] <- vapply(inds, function(v)
-                             mean((k[v] - k[neighbors(g, v)]) /
-                                  (k[v] + k[neighbors(g, v)])),
-                             numeric(1))
+  A <- as_adj(g, sparse=FALSE, names=FALSE)
+  k <- colSums(A)
+  lev.cent <- rep(NA, nrow(A))
+  for (i in which(k > 0)) {
+    lev.cent[i] <- mean((k[i] - k[A[i, ] == 1]) / (k[i] + k[A[i, ] == 1]))
   }
 
   lev.cent <- ifelse(is.nan(lev.cent), NA, lev.cent)
